package com.huiju.welcome.common.base;

import java.io.Serializable;

/**
 * 接口统一状态返回BEAN.
 */
public class ResponseBean<T> implements Serializable {

    private static final long serialVersionUID = 3593827217136880822L;

    private int code = 200;

    private String message = "成功";

    private T data;

    public ResponseBean() {
    }

    public void addDefaultError() {
        this.code = 400;
        this.message = "失败";
    }

    public void addError(String message) {
        this.code = 400;
        this.message = message;
    }

    public void addError(int code, String message) {
        this.code = code;
        this.message = message;
    }

    public void addSuccess(String message) {
        this.message = message;
    }

    public void addSuccess(T data) {
        this.data = data;
    }

    public T getData() {
        return this.data;
    }

    public int getCode() {
        return this.code;
    }

    public String getMessage() {
        return this.message;
    }

    public static <T> ResponseBean success(T data, String ...msgs) {
        ResponseBean responseBean = new ResponseBean();
        responseBean.code = 200;
        responseBean.data = data;

        if (null != msgs && msgs.length > 0) {
            responseBean.message = msgs[0];
        }

        return responseBean;
    }

    public static <T> ResponseBean error(String msg, int code, T ...datas) {
        ResponseBean responseBean = new ResponseBean();
        responseBean.code = code;
        responseBean.message = msg;

        if (null != datas && datas.length > 0) {
            responseBean.data = datas[0];
        }

        return responseBean;
    }

    public void setCode(int code) {
        this.code = code;
    }

    @Override
    public String toString() {
        return  "{ code: "+code+", message: "+message+", data: <T> }";
    }
}
